@@ -84,6 +84,9 @@ __EXPORT char *strip(const char *cs, char *str, size_t len = 0);
 __EXPORT size_t strchop(const char *cs, char *str, size_t len = 0);
 __EXPORT size_t strtrim(const char *cs, char *str, size_t len = 0);
 
+inline char *dupString(const char *src, size_t size = 0)
+	{return newString(src, size);};
+
 /*
 class keystring
 {
