@@ -959,8 +959,11 @@ void Thread::terminate(void)
 		CloseHandle(hThread);
 		hThread = NULL;
 	}
-	if(_parent)
-		_parent->notify(this);
+
+// what if parent already exited?
+
+//	if(_parent)
+//		_parent->notify(this);
 	if(priv->_cancellation != NULL)
 		CloseHandle(priv->_cancellation);
 	priv->_cancellation = NULL;
@@ -1039,8 +1042,8 @@ void Thread::close()
 		PosixThread::_arm.leaveMutex();
 #endif
 	setCancel(cancelDisabled);
-	if(_parent)
-		_parent->notify(this);
+//	if(_parent)
+//		_parent->notify(this);
       
 	// final can call destructor (that call Terminate)
 	final();
